# Vex-Cog-Utils

If you've come here on PyPI, hello! You're welcome to use this wherever, just be aware it requires ``Red-DiscordBot`` which is not in the requirements due to the circumstances this is used by myself.

---

Utility functions for the Vex-Cogs repo, for Red-DiscordBot

There is nothing stopping you from using this in your own cogs, however some of the stuff here is geared towards my cogs. I would recommend you pin the version.

Docstrings fully document each function.

## Versioning

``major.minor.patch``

Major releases are likely to include breaking changes. There **can** me breaking changes in minor releases. There will be nothing breaking in patch releases.

## Changelog

I will endeavour to keep a basic changelog in the ``CHANGELOG.md`` file.

## Contributing

If you want to open a PR, go ahead! I don't really see much need as this is geared towards my cogs but I will probably accept it.

This repo as some tests in tox and a checks workflow.
